# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "BlockRetrieveResponse",
    "BlockRetrieveResponseData",
    "BlockRetrieveResponseDataEntry",
    "BlockRetrieveResponseDataEntryConfiguration",
    "BlockRetrieveResponseDataEntryConfigurationTrip",
    "BlockRetrieveResponseDataEntryConfigurationTripBlockStopTime",
    "BlockRetrieveResponseDataEntryConfigurationTripBlockStopTimeStopTime",
]


class BlockRetrieveResponseDataEntryConfigurationTripBlockStopTimeStopTime(BaseModel):
    arrival_time: int = FieldInfo(alias="arrivalTime")

    departure_time: int = FieldInfo(alias="departureTime")

    stop_id: str = FieldInfo(alias="stopId")

    drop_off_type: Optional[int] = FieldInfo(alias="dropOffType", default=None)

    pickup_type: Optional[int] = FieldInfo(alias="pickupType", default=None)


class BlockRetrieveResponseDataEntryConfigurationTripBlockStopTime(BaseModel):
    accumulated_slack_time: float = FieldInfo(alias="accumulatedSlackTime")

    block_sequence: int = FieldInfo(alias="blockSequence")

    distance_along_block: float = FieldInfo(alias="distanceAlongBlock")

    stop_time: BlockRetrieveResponseDataEntryConfigurationTripBlockStopTimeStopTime = FieldInfo(alias="stopTime")


class BlockRetrieveResponseDataEntryConfigurationTrip(BaseModel):
    accumulated_slack_time: float = FieldInfo(alias="accumulatedSlackTime")

    block_stop_times: List[BlockRetrieveResponseDataEntryConfigurationTripBlockStopTime] = FieldInfo(
        alias="blockStopTimes"
    )

    distance_along_block: float = FieldInfo(alias="distanceAlongBlock")

    trip_id: str = FieldInfo(alias="tripId")


class BlockRetrieveResponseDataEntryConfiguration(BaseModel):
    active_service_ids: List[str] = FieldInfo(alias="activeServiceIds")

    trips: List[BlockRetrieveResponseDataEntryConfigurationTrip]

    inactive_service_ids: Optional[List[str]] = FieldInfo(alias="inactiveServiceIds", default=None)


class BlockRetrieveResponseDataEntry(BaseModel):
    id: str

    configurations: List[BlockRetrieveResponseDataEntryConfiguration]


class BlockRetrieveResponseData(BaseModel):
    entry: BlockRetrieveResponseDataEntry

    references: References


class BlockRetrieveResponse(ResponseWrapper):
    data: BlockRetrieveResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["SearchForStopListResponse", "SearchForStopListResponseData", "SearchForStopListResponseDataList"]


class SearchForStopListResponseDataList(BaseModel):
    id: str

    lat: float

    location_type: int = FieldInfo(alias="locationType")

    lon: float

    name: str

    parent: str

    route_ids: List[str] = FieldInfo(alias="routeIds")

    static_route_ids: List[str] = FieldInfo(alias="staticRouteIds")

    code: Optional[str] = None

    direction: Optional[str] = None

    wheelchair_boarding: Optional[str] = FieldInfo(alias="wheelchairBoarding", default=None)


class SearchForStopListResponseData(BaseModel):
    limit_exceeded: bool = FieldInfo(alias="limitExceeded")

    list: List[SearchForStopListResponseDataList]

    out_of_range: bool = FieldInfo(alias="outOfRange")

    references: References


class SearchForStopListResponse(ResponseWrapper):
    data: Optional[SearchForStopListResponseData] = None



from helpers.load_env import load_settings

from onebusaway import OnebusawaySDK

# Load settings from .env file, if it exists. If not, we'll use the
# Puget Sound server URL (which is also the default in the SDK) and
# the 'TEST' API key.
settings = load_settings(
    {
        "api_key": "TEST",
        "base_url": "https://api.pugetsound.onebusaway.org/",
    }
)

# Create a new instance of the OneBusAway SDK with the settings we loaded.
oba = OnebusawaySDK(**settings)

# Define the query parameters
query = {
    "tripId": "1_604670535",  # Replace with actual trip ID
    "serviceDate": "1810918000000",  # Replace with actual service date in milliseconds since epoch
}

stopId = "1_75403"  # Replace with actual stop ID

# Retrieve arrival and departure information
response = oba.arrival_and_departure.list(stopId, extra_query=query)

# Example to access specific data
arrivals_and_departures = response.data.entry.arrivals_and_departures

for arr_dep in arrivals_and_departures:
    print(f"Route: {arr_dep.route_short_name}")
    print(f"Trip Headsign: {arr_dep.trip_headsign}")
    print(f"Predicted Arrival Time: {arr_dep.predicted_arrival_time}")
    print(f"Scheduled Arrival Time: {arr_dep.scheduled_arrival_time}")
    print(f"Vehicle ID: {arr_dep.vehicle_id}")
    print("")
